[nagiosplug] check_snmp: Allocate space for the new -Le option

Nagios Plugin Development nagios-plugins at users.sourceforge.net
Sun Aug 18 19:10:17 CEST 2013


 Module: nagiosplug
 Branch: master
 Commit: e6bcf116537883ea856b6032f1375e94483963f7
 Author: Holger Weiss <holger at zedat.fu-berlin.de>
   Date: Sun Aug 18 19:08:04 2013 +0200
    URL: http://nagiosplug.git.sf.net/git/gitweb.cgi?p=nagiosplug/nagiosplug;a=commit;h=e6bcf11

check_snmp: Allocate space for the new -Le option

Closes #41.

---

 plugins/check_snmp.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/plugins/check_snmp.c b/plugins/check_snmp.c
index b79c020..3e8a9cf 100644
--- a/plugins/check_snmp.c
+++ b/plugins/check_snmp.c
@@ -274,8 +274,8 @@ main (int argc, char **argv)
 		snmpcmd = strdup (PATH_TO_SNMPGET);
 	}
 
-	/* 9 arguments to pass before authpriv options + 1 for host and numoids. Add one for terminating NULL */
-	command_line = calloc (9 + numauthpriv + 1 + numoids + 1, sizeof (char *));
+	/* 10 arguments to pass before authpriv options + 1 for host and numoids. Add one for terminating NULL */
+	command_line = calloc (10 + numauthpriv + 1 + numoids + 1, sizeof (char *));
 	command_line[0] = snmpcmd;
 	command_line[1] = strdup ("-Le");
 	command_line[2] = strdup ("-t");





More information about the Commits mailing list